.. scikit-hubness documentation master file, created by
   sphinx-quickstart on Mon Jul  8 13:54:25 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

`scikit-hubness`: high-dimensional data mining
================================================

``scikit-hubness`` is a Python package for analysis of hubness
in high-dimensional data. It provides hubness reduction and
approximate nearest neighbor search via a drop-in replacement for
`sklearn.neighbors <https://scikit-learn.org/stable/modules/classes.html#module-sklearn.neighbors>`_.

.. toctree::
   :maxdepth: 1
   :hidden:
   :caption: Getting Started

   Installation <getting_started/installation>
   Quick start example <getting_started/example>

.. toctree::
   :maxdepth: 3
   :hidden:
   :caption: Documentation

   User Guide <documentation/user_guide>
   scikit-hubness API <documentation/documentation>
   History <documentation/history>

.. toctree::
   :maxdepth: 2
   :titlesonly:
   :hidden:
   :caption: Development

   Contributing <development/contributing>
   Github Repository <https://github.com/VarIr/scikit-hubness>
   What's new (Changelog) <changelog.md>


`Getting started <getting_started/installation.html>`_
-------------------------------------------------------

Get started with ``scikit-hubness`` in a breeze.
Find how to `install the package <getting_started/installation.html>`_ and
see all core functionality applied in a single `quick start example <getting_started/example.html>`_.


`User Guide <documentation/user_guide.html>`_
-----------------------------------------------

The `User Guide <documentation/user_guide.html>`_ introduces the main concepts of ``scikit-hubness``.
It explains, how to analyze your data sets for hubness,
and how to use the package to lift this *curse of dimensionality*.
You will also find examples how to use ``skhubness.neighbors``
for approximate nearest neighbor search (with or without hubness reduction).


`API Documentation <documentation/documentation.html>`_
--------------------------------------------------------

The `API Documentation <documentation/documentation.html>`_ provides detailed information
of the implemented methods.
This information includes method descriptions, parameters, references, examples, etc.
Find all the information about specific modules and functions of ``scikit-hubness`` in this section.


`History <documentation/history.html>`_
----------------------------------------

A `brief history <documentation/history.html>`_ of the package,
and how it relates to the ``Hub-Toolbox``'es.


`Development <development/contributing.html>`_
-----------------------------------------------

There are several possibilities to `contribute <development/contributing.html>`_
to this free open source software. We highly appreciate all input from the community,
be it bug reports or code contributions.

Source code, issue tracking, discussion, and continuous integration appear on
our `GitHub page <https://github.com/VarIr/scikit-hubness>`_.


`What's new <changelog.html>`_
--------------------------------

To see what's new in the latest version of ``scikit-hubness``,
have a look at the `changelog <changelog.html>`_.
